#define SPDLOG_ACTIVE_LEVEL SPDLOG_LEVEL_DEBUG
#include "spdlog/spdlog.h"
#include "spdlog/sinks/udp_sink.h"
#include "spdlog/sinks/stdout_color_sinks.h"
#include <string>

#define SLOG_TRACE(args...) spin_logger->trace(args)
#define SLOG_DEBUG(args...) spin_logger->debug(args)
#define SLOG_INFO(args...) spin_logger->info(args)
#define SLOG_WARN(args...) spin_logger->warn(args)
#define SLOG_ERROR(args...) spin_logger->error(args)
#define SLOG_CRITICAL(args...) spin_logger->critical(args)
// or just use SPDLOG_CRITICAL("message") etc.

namespace
{
    std::shared_ptr<spdlog::logger> spin_logger;
}

inline void initialize_spin_logger(const std::string &name, const std::string &udpHost = "127.0.0.1", const int udpPort = 514)
{
    if (spdlog::get(name) == nullptr)
    {
        spdlog::sinks::udp_sink_config config(udpHost, udpPort);
        auto udp_sink = std::make_shared<spdlog::sinks::udp_sink_mt>(config);
        auto console_sink = std::make_shared<spdlog::sinks::stdout_color_sink_mt>();
        auto multiLogger = std::make_shared<spdlog::logger>(name, std::initializer_list<spdlog::sink_ptr>{console_sink, udp_sink});
        spdlog::register_logger(multiLogger);
        spin_logger = spdlog::get(name);
        spdlog::set_default_logger(spin_logger);
    }
}